==> ocp_0.1.9.orig.tar.gz: ocp-0.1.9/filesel/fsptype.c <==
/* OpenCP Module Player
 * copyright (c) '94-'05 Niklas Beisert <nbeisert@physik.tu-muenchen.de>
 *
 * Fileselector file type detection routines (covers play lists and internal
 * cache files)
 *
 * revision history: (please note changes here)
 *  -kb980717   Tammo Hinrichs <opencp@gmx.net>
 *    -first release
 */

#include "config.h"
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include "types.h"
#include "mdb.h"

static int fsReadMemInfo(struct moduleinfostruct *m, const char *buf, size_t len)
{
  /* check for PLS play list */

	char *b=(char *)buf;
	int pos=10;
	int num=0;
	char linebuf[512];

	if (!memcmp(buf,"[playlist]", 10))
	{
		while (pos<len)
		{
			if (b[pos]!=0x0a && b[pos]!=0x0d)
				pos++;
			else {
				while (isspace(b[pos]) && pos<len)
					pos++;
				if (len-pos>18 && !memcmp(b+pos,"NumberOfEntries=",16))
				{
					pos+=16;
					num=strtol(b+pos,0,10);
					pos=len;
				}
			}
		}
		if (num)
		{
			sprintf(m->modname, "PLS style play list (%d entries)", num);
			m->modtype=mtPLS;
			return 1;
		} else {
			strcpy(m->modname,"PLS style play list ?");
			m->modtype=mtPLS;
			return 1;
		}
	}

 /* check for M3U-style play list */
	pos=0;
	num=0;
	while (pos<len)
	{
		int pos2;
		while (pos<len && isspace(b[pos]))
			pos++;
		if (pos>=len)
			break;
		pos2=pos;
		while(pos2<len && b[pos2]>=32)
			pos2++;
		if ((pos2<len && b[pos2]!=0x0A && b[pos2]!=0x0D) || (pos2-pos)>=512)
		{
			num=0;
			break;
		}
		if (pos2==len)
		{
			num=-1;
			break;
		}
		memcpy(linebuf,b+pos,pos2-pos);
		linebuf[pos2-pos]=0;
		if (strchr(linebuf,';'))
			*strchr(linebuf,';')=0;
		if (*linebuf && !strchr(linebuf,'.'))
		{
			num=0;
			break;
		}
		num++;
		pos=pos2+1;
	}
	if (num>0)
	{
		sprintf(m->modname, "M3U style play list (%d entries)", num);
		m->modtype=mtM3U;
		return 1;
	} else if (num<0)
	{
		strcpy(m->modname,"M3U play list ?");
		m->modtype=mtM3U;
		return 1;
	}
	if (!memcmp(buf, "CPArchiveCache\x1B\x00", 16))
		strcpy(m->modname,"openCP archive data base (old)");
	if (!memcmp(buf, "CPArchiveCache\x1B\x01", 16))
		strcpy(m->modname,"openCP archive data base");
	if (!memcmp(buf, "Cubic Player Module Information Data Base\x1B\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 60))
		strcpy(m->modname,"openCP module info data base");
	if (!memcmp(buf, "Cubic Player MediaLib Information Data Base\x1B\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 56))
		strcpy(m->modname,"Cubic Player MediaLib Data Base");
	if (!memcmp(buf, "MDZTagList\x1A\x00", 12))
		strcpy(m->modname,"openCP MDZ file cache");

	m->modtype=0xFF;
	return 0;
}

static int fsReadInfo(struct moduleinfostruct *m, FILE *fp, const char *buf, size_t len)
{
	return 0;
}

struct mdbreadnforegstruct fsReadInfoReg = {fsReadMemInfo, fsReadInfo};

==> ocp_0.1.10rc5.orig.tar.gz: ocp-0.1.10rc5/filesel/fsptype.c <==
/* OpenCP Module Player
 * copyright (c) '94-'05 Niklas Beisert <nbeisert@physik.tu-muenchen.de>
 *
 * Fileselector file type detection routines (covers play lists and internal
 * cache files)
 *
 * revision history: (please note changes here)
 *  -kb980717   Tammo Hinrichs <opencp@gmx.net>
 *    -first release
 */

#include "config.h"
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include "types.h"
#include "mdb.h"

static int fsReadMemInfo(struct moduleinfostruct *m, const char *buf, size_t len)
{
  /* check for PLS play list */

	char *b=(char *)buf;
	int pos=10;
	int num=0;

	if (!memcmp(buf,"[playlist]", 10))
	{
		while (pos<len)
		{
			if (b[pos]!=0x0a && b[pos]!=0x0d)
				pos++;
			else {
				while (isspace(b[pos]) && pos<len)
					pos++;
				if (len-pos>18 && !memcmp(b+pos,"NumberOfEntries=",16))
				{
					pos+=16;
					num=strtol(b+pos,0,10);
					pos=len;
				}
			}
		}
		if (num)
		{
			sprintf(m->modname, "PLS style play list (%d entries)", num);
			m->modtype=mtPLS;
			m->flags1|=MDB_PLAYLIST;
			return 1;
		} else {
			strcpy(m->modname,"PLS style play list ?");
			m->modtype=mtPLS;
			m->flags1|=MDB_PLAYLIST;
			return 1;
		}
	}

 /* check for M3U-style play list */
	if (!memcmp(buf,"#EXTM3U", 7))
	{
		strcpy(m->modname,"M3U play list");
		m->modtype=mtM3U;
		m->flags1|=MDB_PLAYLIST;
		return 1;
	}

	if (!memcmp(buf, "CPArchiveCache\x1B\x00", 16))
		strcpy(m->modname,"openCP archive data base (old)");
	if (!memcmp(buf, "CPArchiveCache\x1B\x01", 16))
		strcpy(m->modname,"openCP archive data base");
	if (!memcmp(buf, "Cubic Player Module Information Data Base\x1B\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 60))
		strcpy(m->modname,"openCP module info data base");
	if (!memcmp(buf, "Cubic Player MediaLib Information Data Base\x1B\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 56))
		strcpy(m->modname,"openCP medialib: data base");
	if (!memcmp(buf, "MDZTagList\x1A\x00", 12))
		strcpy(m->modname,"openCP MDZ file cache");

	m->modtype=0xFF;
	return 0;
}

static int fsReadInfo(struct moduleinfostruct *m, FILE *fp, const char *buf, size_t len)
{
	return 0;
}

struct mdbreadnforegstruct fsReadInfoReg = {fsReadMemInfo, fsReadInfo};
